@@ -1,7 +1,7 @@
 /*
 
     EnergyMech, IRC bot software
-    Copyright (c) 1997-2005 proton
+    Copyright (c) 1997-2008 proton
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,8 +40,8 @@
 #define DEFAULTCMDCHAR			'-'
 #define MECHUSERLOGIN			"v3.energymech.net"
 
-BEG const char VERSION[]		MDEF("3.0.2");
-BEG const char SRCDATE[]		MDEF("May 8th, 2006");
+BEG const char VERSION[]		MDEF("3.0.3");
+BEG const char SRCDATE[]		MDEF("August 27th, 2008");
 #ifdef __CYGWIN__
 BEG const char BOTCLASS[]		MDEF("WinMech");
 #else /* ! CYGWIN */
